from quickey_python_sdk.config import base_url
import requests

class App():
    def __init__(self, apiKey):
        self.__apiKey = apiKey
        pass
    
    def getAppMetaData(self):
        payload = {'apiKey':self.__apiKey}
        return requests.post('{0}/auth/apiKey'.format(base_url), data=payload)

    def sendOTP(self, phone, provider):
        headers = {'authorization':self.__apiKey}
        payload = {'phone':phone, 'provider':provider}
        return requests.post('{0}/otp/sendToUserPhone'.format(base_url), data=payload, headers=headers)



import quickey_python_sdk
from quickey_python_sdk.config import missing_api_key_message
from quickey_python_sdk.auth import Auth
from quickey_python_sdk.app import App

class QuickeySDK:
    def __init__(self, apiKey):
        self.app = App(apiKey)
        self.auth = Auth(apiKey)

class QuickeySDKError:
    def __init__(self):
        pass

    def setMissingAPiKeyError ():
        return missing_api_key_message



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="quickey-python-sdk",
    version="1.0.13",
    author="quickey team",
    author_email="efrizal@analisa.io",
    description="A Login Management System for Application",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/efrizal-analisa/quickey_python_sdk",
    packages=['quickey_python_sdk'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


from quickey_python_sdk.config import base_url
import requests

class Auth():
    def __init__(self, apiKey):
        self.__apiKey = apiKey
        pass
        
    def getAccessTokenByEmail(self, email, provider):
        headers = {'authorization':self.__apiKey}
        payload = {'email':email, 'provider':provider}
        return requests.post('{0}/loginCustomer'.format(base_url), data=payload, headers=headers)

    def getAccessTokenByPhone(self, phone, provider, otpCode):
        headers = {'authorization':self.__apiKey}
        payload = {'phone':phone, 'provider':provider, 'otpCode':otpCode}
        return requests.post('{0}/loginCustomer'.format(base_url), data=payload, headers=headers)

    def verifyToken(self, token):
        headers = {'authorization':self.__apiKey}
        payload = {'token':token}
        return requests.post('{0}/auth/verifyToken'.format(base_url), data=payload, headers=headers)

    def linkPhoneToEmail(self, phone, token):
        headers = {'authorization':self.__apiKey}
        payload = {'phone':phone, 'token':token}
        return requests.post('{0}/otp/linkToEmail'.format(base_url), data=payload, headers=headers)
